# Create list of standard folder names and store in a configuration file
conf_file <- tempfile("folders.yml") # Using tempfile() for testing only
folders <- get_folders(conf_file)
# Testing only: Append folder names to parent folder path --
# This would NOT be needed or desired in normal usage
folders <- lapply(folders, function(x) file.path(tempdir(), x))
# Create a folder for each item in "folders" list
result <- create_folders(folders)
# Remove empty folders, leaving only those with files or subfolders in them
result <- cleanup_folders(folders)
Run the code above in your browser using DataLab